function [res]=test1(serie)
%function [res]=test1(serie)
% Approximation mit Hilfe von Gauss-Newton. Mit Abbruchbedingung
% und Schrittweiten-Korrektur.
% serie = Nummer der Verifikationsmessung.
% res[1]  : berechneter ed50-Wert
% res[2]  : berechneter ed95-Wert
% res[3]  : Summe der Residuen^2
% res[4,5]: Parameter a und b 
% res[6]  : Anahl Iterationen

% Lade die Daten der Verifikationsmessungen
load data

% Konzentration des Fungizids in [mg/l]
x=[0.0001,0.0003,0.001,0.003,0.01,0.03,0.1,0.3,1,10]';

% Hemmung aus den Daten bestimmen 
y= data(10*serie-9:10*serie,2)/100;

% Werte um 0 sind nicht gut...
for i=1:10,
  if abs(y(i)) <0.0001,
    y(i) = 0.0001;
  end
end

A= [ones(size(x)),log(x)];

% Startwert ermitteln
[a,b]=startwert(0,10,0,2,x,y);
koeff=[a;b];   
% input('press any key);   % Zur Kontrolle


% Sigmoid-Funktion zur Kontrolle des Anfangswerts plotten
% ys = 1 ./ (1+exp(-A*koeff));
% semilogx(x,ys,x,y,'o',x,y);

% "Fehlerlandschaft" plotten
% a= linspace(1.8,2.2,40);
% b= linspace(0.3,0.5,40);
 a= linspace(2.8,3.2,40);
 b= linspace(1.15,1.25,40);
 for ai= 1:length(a),
   for bi=1:length(b),
     ys = 1 ./ (1+exp(-(a(ai)+b(bi)*log(x)))); 
     z(ai,bi)=norm(ys-y);
  end;
 end;
 mesh(b,a,z)
 input('press any key');

Nmin=1000;

step=0.5;
% Gauss-Newton-Iteration
for iter = 1:1000,
  k(:,iter+1)=koeff;

  % Funktionswert berechnen 
  h = exp(-A*koeff);  % Hilfsvariable
  F= 1 ./ (1+h)-y;
  n(iter)=norm(F)^2;            % Zur Kontrolle

  % Jacobi-Vektor berechnen
  J(:,1)= h ./ ((1+h).^2);
  J(:,2)= log(x).*J(:,1);

  % Schrittweite anpassen
  if (mod(iter,10) == 0),
    if (std(n(iter-5:iter)) > 0.01) & (step > 0.05),
      step = step / 2;
    end
  end
  if (mod(iter,50) == 0),  
    % Abbruch-Bedingung testen
    if (max(n(iter-20:iter)) - min(n(iter-20:iter))) < 0.0001*n(iter),
      break
    end
    if (std(n(iter-5:iter)) < 0.001) & (step <1.0)
      step=step*1.5;
    end
  end
  s(iter) =step;
  
  % Neuen Vektor mit Koeffizienten berechnen
  koeff = koeff - step*J'*F;
  
  % Merke Dir jeweils das Minimum
  if n(iter) < Nmin,
    Nmin=n(iter);
    Kmin=koeff;
  end
  
end

%ED50 und ED95-Werte berechnen
ed50=exp(-Kmin(1)/Kmin(2));  % = 0.0183233
ed95=exp((-log(0.05/0.95)-Kmin(1))/Kmin(2));

res(1)=ed50; res(2)=ed95; res(3)=Nmin; res(4:5)=Kmin; res(6)=iter;

% Kontroll-Plots
% plot(n)              % Verlauf der norm
% contour(b,a,z,60)    % Fehlerlandschaft von oben
% hold on;
% plot(k(2,:),k(1,:))  % Verlauf der Koeff in der Fehlerlandschaft 
% hold off
% input('press any key');

% Zur Kontrolle noch Messpunkte und Kurve aufzeichnen
x1=logspace(-4,1,100);
y1 = 1 ./ (1+exp(-Kmin(1)-Kmin(2)*log(x1)));
semilogx(x1,y1,x,y,x,y,'o')
